@@ -1,9 +1,9 @@
 #include "raster.h"
 
 
-RasterData* NewRasterData(int nrow, int ncol)
+RasterData* RasterData_new(int nrow, int ncol)
 {
-    RasterData *rd = (RasterData *) malloc(sizeof(RasterData));
+    RasterData* rd = (RasterData*) malloc(sizeof(RasterData));
     int i;
     
     rd->nrow = nrow;
@@ -16,10 +16,11 @@ RasterData* NewRasterData(int nrow, int ncol)
     return rd;
 }
 
-void FreeRasterData(RasterData *rd)
+void RasterData_destroy(RasterData* rd)
 {
-    if(rd && rd->data)  free(rd->data);
-    if(rd)  free(rd);
+    if(!rd) return;
+    if(rd->data)  free(rd->data);
+    if(rd)        free(rd);
 }
 
 
@@ -27,8 +28,8 @@ void FreeRasterData(RasterData *rd)
 /* Write bitmap to the matrix
    The upper-left corner of the bitmap will be written to matrix(i, j),
    i.e., matrix(i + s, j + t) = buffer(s, t) */
-static void WriteMatrix(const FT_Bitmap *bitmap, RasterData *mat, int mi, int mj,
-                        const pGEcontext gc)
+static void write_matrix(const FT_Bitmap* bitmap, RasterData* mat, int mi, int mj,
+                         const pGEcontext gc)
 {
     /* Bitmap is stored by row, starting from the upperleft corner.
        Therefore, the pixel in the p-th row and q-th column (0-based) is
@@ -58,12 +59,12 @@ static void WriteMatrix(const FT_Bitmap *bitmap, RasterData *mat, int mi, int mj
     }
 }
 
-RasterData* GetStringRasterImage(unsigned int *unicode, int nchar,
-                                 int psizeX, int psizeY,
-                                 double rad, double hadj, const pGEcontext gc,
-                                 double *centerH, double *centerV)
+RasterData* get_string_raster_image(unsigned int* unicode, int nchar,
+                                    int px_size_x, int px_size_y,
+                                    double rad, double hadj, const pGEcontext gc,
+                                    double* center_horiz, double* center_vert)
 {
-    FT_Face face = GetFTFace(gc);
+    FT_Face face = get_ft_face(gc);
     FT_GlyphSlot slot = face->glyph;
     FT_Matrix trans;
     FT_Vector pen;
@@ -81,11 +82,11 @@ RasterData* GetStringRasterImage(unsigned int *unicode, int nchar,
     int mi = 0, mj = 0, i;
     
     /* Set pixel size */
-    err = FT_Set_Pixel_Sizes(face, psizeX, psizeY);
-    if(err)  FTError(err);
+    err = FT_Set_Pixel_Sizes(face, px_size_x, px_size_y);
+    if(err)  forward_ft_error(err);
 
     /* Get bounding box when no transformation is applied */
-    GetStringBBox(face, unicode, nchar, 0.0, &xmin, &xmax, &ymin, &ymax);
+    get_string_bbox(face, unicode, nchar, 0.0, &xmin, &xmax, &ymin, &ymax);
     /* Calculate the alignment center before transformation */
     cx = hadj * xmax + (1 - hadj) * xmin;
     cy = 0.0;
@@ -96,11 +97,11 @@ RasterData* GetStringRasterImage(unsigned int *unicode, int nchar,
     cx = cx * cosr;
     
     /* Calculate bounding box when transformation is applied */
-    GetStringBBox(face, unicode, nchar, rad, &xmin, &xmax, &ymin, &ymax);
+    get_string_bbox(face, unicode, nchar, rad, &xmin, &xmax, &ymin, &ymax);
     /* Calculate the horizontal and vertical distance from the alignment center
        to the bottom-left corner of the (new) bounding box */
-    *centerH = cx - xmin;
-    *centerV = cy - ymin;
+    *center_horiz = cx - xmin;
+    *center_vert = cy - ymin;
     
     /* Set transformation */
     trans.xx = trans.yy = (FT_Fixed)(cosr * 0x10000L);
@@ -109,14 +110,14 @@ RasterData* GetStringRasterImage(unsigned int *unicode, int nchar,
     pen.x = pen.y = 0;
     
     /* Create raster data */
-    rd = NewRasterData(ymax - ymin, xmax - xmin);
+    rd = RasterData_new(ymax - ymin, xmax - xmin);
     for(i = 0; i < nchar; i++)
     {
         FT_Set_Transform(face, &trans, &pen);
         FT_Load_Char(face, unicode[i], FT_LOAD_RENDER);
         mi = ymax - slot->bitmap_top;
         mj = slot->bitmap_left - xmin;
-        WriteMatrix(&(slot->bitmap), rd, mi, mj, gc);
+        write_matrix(&(slot->bitmap), rd, mi, mj, gc);
         pen.x += slot->advance.x;
         pen.y += slot->advance.y;
     }
